@@ -35,24 +35,38 @@
 
 #include <QRegularExpression>
 
+#include "base/global.h"
 #include "infohash.h"
 
 namespace
 {
-    bool isSHA1Hash(const QString &string)
+    // BEP9 Extension for Peers to Send Metadata Files
+
+    bool isV1Hash(const QString &string)
     {
-        // There are 2 representations for BitTorrent info hash:
+        // There are 2 representations for BitTorrent v1 info hash:
         // 1. 40 chars hex-encoded string
         //      == 20 (SHA-1 length in bytes) * 2 (each byte maps to 2 hex characters)
         // 2. 32 chars Base32 encoded string
         //      == 20 (SHA-1 length in bytes) * 1.6 (the efficiency of Base32 encoding)
-        const int SHA1_HEX_SIZE = SHA1Hash::length() * 2;
-        const int SHA1_BASE32_SIZE = SHA1Hash::length() * 1.6;
+        const int V1_HEX_SIZE = SHA1Hash::length() * 2;
+        const int V1_BASE32_SIZE = SHA1Hash::length() * 1.6;
 
-        return ((((string.size() == SHA1_HEX_SIZE))
-                && !string.contains(QRegularExpression(QLatin1String("[^0-9A-Fa-f]"))))
-            || ((string.size() == SHA1_BASE32_SIZE)
-                && !string.contains(QRegularExpression(QLatin1String("[^2-7A-Za-z]")))));
+        return ((((string.size() == V1_HEX_SIZE))
+                && !string.contains(QRegularExpression(u"[^0-9A-Fa-f]"_qs)))
+            || ((string.size() == V1_BASE32_SIZE)
+                && !string.contains(QRegularExpression(u"[^2-7A-Za-z]"_qs))));
+    }
+
+    bool isV2Hash(const QString &string)
+    {
+        // There are 1 representation for BitTorrent v2 info hash:
+        // 1. 64 chars hex-encoded string
+        //      == 32 (SHA-2 256 length in bytes) * 2 (each byte maps to 2 hex characters)
+        const int V2_HEX_SIZE = SHA256Hash::length() * 2;
+
+        return (string.size() == V2_HEX_SIZE)
+                && !string.contains(QRegularExpression(u"[^0-9A-Fa-f]"_qs));
     }
 }
 
@@ -66,8 +80,10 @@ MagnetUri::MagnetUri(const QString &source)
 {
     if (source.isEmpty()) return;
 
-    if (isSHA1Hash(source))
-        m_url = QLatin1String("magnet:?xt=urn:btih:") + source;
+    if (isV2Hash(source))
+        m_url = u"magnet:?xt=urn:btmh:1220" + source; // 0x12 0x20 is the "multihash format" tag for the SHA-256 hashing scheme.
+    else if (isV1Hash(source))
+        m_url = u"magnet:?xt=urn:btih:" + source;
 
     lt::error_code ec;
     lt::parse_magnet_uri(m_url.toStdString(), m_addTorrentParams, ec);
@@ -75,7 +91,7 @@ MagnetUri::MagnetUri(const QString &source)
 
     m_valid = true;
 
-#if (LIBTORRENT_VERSION_NUM >= 20000)
+#ifdef QBT_USES_LIBTORRENT2
     m_infoHash = m_addTorrentParams.info_hashes;
 #else
     m_infoHash = m_addTorrentParams.info_hash;
@@ -84,8 +100,15 @@ MagnetUri::MagnetUri(const QString &source)
     m_name = QString::fromStdString(m_addTorrentParams.name);
 
     m_trackers.reserve(static_cast<decltype(m_trackers)::size_type>(m_addTorrentParams.trackers.size()));
-    for (const std::string &tracker : m_addTorrentParams.trackers)
-        m_trackers.append({QString::fromStdString(tracker)});
+    int tier = 0;
+    auto tierIter = m_addTorrentParams.tracker_tiers.cbegin();
+    for (const std::string &url : m_addTorrentParams.trackers)
+    {
+        if (tierIter != m_addTorrentParams.tracker_tiers.cend())
+            tier = *tierIter++;
+
+        m_trackers.append({QString::fromStdString(url), tier});
+    }
 
     m_urlSeeds.reserve(static_cast<decltype(m_urlSeeds)::size_type>(m_addTorrentParams.url_seeds.size()));
     for (const std::string &urlSeed : m_addTorrentParams.url_seeds)
